# This file replicates the analyses reported in 
# Gleditsch and Ruggeri JPR
# 
# Please direct all questions to Kristian Skrede Gleditsch
# at ksg@essex.ac.uk
#
# This version: 8 December 2009

# Set working directory
setwd("C:/work/work14/oppstruct/")

glerug <- read.table("glerug.asc",header=T)

# Model 1
m1 <- glm(onset ~ log(rgdp96pc) 
    + polityksg 
    + I(polityksg^2) 
    + I(POLITY==(-66)) 
    + I(POLITY==(-77))
    + I(POLITY==(-88))
    + log(pop) 
    + exp(-py/4),
    family=binomial, data=glerug, na.action=na.omit,model=T) 
summary(m1)

# Model 2
m2 <- glm(onset ~ log(rgdp96pc) 
    + polityksg 
    + I(polityksg^2) 
    + I(POLITY==(-77)) 
    + I(POLITY==(-88))
    + I(PARCOMP==0 | PARCOMP==1) 
    + I(PARREG==1 | PARREG==2)    
    + log(pop) 
    + exp(-py/4) 
    + I(irrtrans>0 | itlag>0) ,
    family=binomial, data=glerug, na.action=na.omit,model=T) 
summary(m2)

# Model 3
m3 <- glm(onset ~ log(rgdp96pc) 
    +  polityksg 
    + I(POLITY==(-77)) 
    + I(POLITY==(-88))
    + I(PARCOMP==0 | PARCOMP==1) 
    + I(PARREG==1 | PARREG==2)    
    + log(pop) 
    + exp(-py/4) 
    + I(irrtrans>0 | itlag>0) ,
    family=binomial, data=glerug, na.action=na.omit,model=T) 
summary(m3)

# Model 4 (instrument for irregular entry)
library(foreign)
trans <- read.dta("transv1.dta")

joint <- merge(glerug,trans[,c("id","pgr","pnbdem","timdep","catho80","muslim80","catpv2","pvatican2")],
    by.x="oid",by.y="id",all.x=T)

aux <- glm(I(irrtrans>0 | itlag>0) ~
    log(rgdp96pc) +  polityksg + I(POLITY==(-77)) 
    + I(POLITY==(-88))  + I(PARCOMP==0 | PARCOMP==1) 
    + I(PARREG==1 | PARREG==2) + log(pop) + exp(-py/4) 
    + I(entry > 0) + log((tenure/365) + 1) 
    + I((entry > 0) * log((tenure/365) + 1))
    + pgr + prevdem + pnbdem + timdep + catho80 + muslim80 + catpv2 + pvatican2,
    data=joint, family=binomial, na.action=na.omit)

linpred <- predict(aux)
linpred <- data.frame(names(linpred),linpred)
joint <- merge(joint,linpred,by="row.names",all.x=T)

m3.instr <- glm(onset ~ log(rgdp96pc) 
    +  polityksg 
    + I(POLITY==(-77)) 
    + I(POLITY==(-88))
    + I(PARCOMP==0 | PARCOMP==1) 
    + I(PARREG==1 | PARREG==2)    
    + log(pop) 
    + exp(-py/4) 
    + linpred ,
    family=binomial, data=joint, na.action=na.omit,model=T) 
summary(m3.instr)

library(boot)
boot.m3 <- function(data, indices, maxit=20){
    data <- data[indices,] # select obs. in bootstrap sample
    mod <- glm(onset ~ log(rgdp96pc) 
        +  polityksg 
        + I(POLITY==(-77)) 
        + I(POLITY==(-88))
        + I(PARCOMP==0 | PARCOMP==1) 
        + I(PARREG==1 | PARREG==2)    
        + log(pop) 
        + exp(-py/4) 
        + linpred,
        family=binomial, data=data, na.action=na.omit, maxit=maxit)
    coefficients(mod) # return coefficient vector
}
m3.boot <- boot(joint, boot.m3, R=2000, maxit=100)

coef.mat <- data.frame(names(m3.instr$coef),m3.instr$coef,NA,NA)
for(i in 1:dim(coef.mat)[1]){
  coef.mat[i,3] <- sqrt(sum((m3.boot$t[,i]-sum(m3.boot$t[,i])/m3.boot$R)^2)/(m3.boot$R-1))
  coef.mat[i,4] <- as.numeric(coef.mat[i,2])/as.numeric(coef.mat[i,3])
}
coef.mat[,2:4] <- round(coef.mat[,2:4],3)
names(coef.mat) <- c("variable","Coef","BSE","Z")

# Model 5
m5 <- glm(onset ~ log(rgdp96pc) 
    + polityksg 
    + I(POLITY==(-77)) 
    + I(POLITY==(-88))
    + I(PARCOMP==0 | PARCOMP==1) 
    + I(PARREG==1 | PARREG==2)    
    + log(pop) 
    + exp(-py/4)
    + I(entry>0) 
    + log((tenure/365)+1)
    + I((entry>0)*log((tenure/365)+1)), model = T,
    family=binomial, data=glerug, na.action=na.omit) 
summary(m5)


# Code to generate Figure 1

# Generare predicted values
hypten <- c(seq(1,100,1),seq(101,7300,25))

# Irregular
pred <- predict(m5,
    data.frame(
        rgdp96pc=median(glerug$rgdp96pc,na.rm=T),
        polityksg=median(glerug$polityksg,na.rm=T),
        POLITY=99,
        PARCOMP=99,
        PARREG=99,
        pop=median(glerug$pop,na.rm=T),
        py= median(glerug$py,na.rm=T),
        entry=1,
        tenure=hypten
    ),se.fit=TRUE)

pred.irreg <- with(pred, cbind(fit,
  low = fit - 1*se.fit,
  up = fit + 1*se.fit)
)

# Regular
pred <- predict(m5,
    data.frame(
        rgdp96pc=median(glerug$rgdp96pc,na.rm=T),
        polityksg=median(glerug$polityksg,na.rm=T),
        POLITY=99,
        PARCOMP=99,
        PARREG=99,
        pop=median(glerug$pop,na.rm=T),
        py= median(glerug$py,na.rm=T),
        entry=0,
        tenure=hypten
    ),se.fit=TRUE)

pred.reg <- with(pred, cbind(fit,
  low = fit - 1*se.fit,
  up = fit + 1*se.fit)
)

jpeg(filename = "GR_JPR_figure1.jpg",
    width = 480, height = 480,
    pointsize = 12, quality = 100, bg = "white", res = NA)
plot(hypten,pred.irreg[,1],
    ylim=c(min(pred.reg,pred.irreg),max(pred.reg,pred.irreg)),
    type="l",
    xlab="Tenure (in days)",ylab="Log odds of conflict")
lines(hypten,pred.irreg[,2],type="l",col="grey")
lines(hypten,pred.irreg[,3],type="l",col="grey")
lines(hypten,pred.reg[,1],type="l",lty=8)
lines(hypten,pred.reg[,2],type="l",lty=8,col="grey")
lines(hypten,pred.reg[,3],type="l",lty=8,col="grey")
legend(x=c(4300, 5000), y=c(-3.00,-2.35), legend=c("Irregular entry","Regular entry"), 
    lty=c(1,8), cex=1, bty="n")
dev.off()

# Model 6
m6 <- glm(onset ~ log(rgdp96pc) 
    + polityksg 
    + I(POLITY==(-77)) 
    + I(POLITY==(-88))
    + I(PARCOMP==0 | PARCOMP==1) 
    + I(PARREG==1 | PARREG==2)    
    + log(pop) 
    + exp(-py/4)
    + I(irrtrans>0 | itlag>0)
    + I(entry>0) 
    + log((tenure/365)+1)
    + I((entry>0)*log((tenure/365)+1)),
    family=binomial, data=isa07, na.action=na.omit) 
summary(m6)
